pygeodesy.ltpTuples.Aer

Package pygeodesy :: Module ltpTuples :: Class Aer |
[frames] | no frames]

# Class Aer

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                _AbcBase --+
                           |
                          Aer

Known Subclasses:
  - Los

Local `Azimuth-Elevation-Range` (AER) in a local tangent plane.

Instance Methods
__init__(self, azimuth_aer, elevation=0, slantrange=0, ltp=None, **name) New Aer. |
toRepr(self, prec=None, fmt='[%s]', sep=', ', **unused) Return a string representation of this AER as azimuth (bearing), elevation and slant range. |
toStr(self, **prec_fmt_sep) Return a string representation of this AER. |
Inherited from `_AbcBase`: `toAer`, `toEnu`, `toNed`, `toXyz` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| aer4 Get the `(azimuth, elevation, slantrange, ltp)` components (Aer4Tuple).
| azimuth Get the Azimuth, bearing from North (`degrees360`).
| down Get the Down component (`meter`).
| east Get the East component (`meter`).
| elevation Get the Elevation, tilt above horizon (`degrees90`).
| groundrange Get the ground range, distance (`meter`).
| north Get the North component (`meter`).
| slantrange Get the slant Range, distance (`meter`).
| up Get the Up component (`meter`).
| x Get the X component (`meter`).
| xyz4 Get the `(x, y, z, ltp)` components (Xyz4Tuple).
| y Get the Y component (`meter`).
| z Get the Z component (`meter`).
Inherited from `_AbcBase`: `ltp`, `xyz`, `xyz3`, `xyzLocal` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, azimuth_aer, elevation=0, slantrange=0, ltp=None, **name) (Constructor) |
New Aer. Arguments: `azimuth_aer` - Scalar azimuth, bearing from North (compass `degrees`) or a previous local instance (Aer, Aer4Tuple, Enu, Enu4Tuple, Local9Tuple, Ned, Ned4Tuple, XyzLocal or Xyz4Tuple). `elevation` - Scalar angle above the horizon, above `ltp` (`degrees`, horizon is 0, zenith +90 and nadir -90), only used with scalar `azimuth_aer`. `slantrange` - Scalar distance (`meter`), only used with scalar `azimuth_aer`. `ltp` - The local tangent plane, (geodetic) origin (Ltp, LocalCartesian). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `azimuth_aer` or `ltp`. `UnitError` - Invalid `azimuth_aer`, `elevation` or or `slantrange`. Overrides: object.__init__

### toRepr (self, prec=None, fmt='[%s]', sep=', ', **unused) |
Return a string representation of this AER as azimuth (bearing), elevation and slant range. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `fmt` - Enclosing backets format (`str`). `sep` - Optional separator between AERs (`str`). Returns: This AER as "[A:degrees360, E:degrees90, R:meter]" (`str`). Overrides: named._Named.toRepr

### toStr (self, **prec_fmt_sep) |
Return a string representation of this AER. Arguments: `prec_fmt_sep` - Keyword arguments `prec=3` for the number of (decimal) digits, unstripped (`int`), `fmt='[]'` the enclosing backets format (`str`) and separator `sep=", "` to join (`str`). Returns: This AER as "[degrees360, degrees90, meter]" (`str`). Overrides: named._Named.toStr

Property Details

### aer4 Get the `(azimuth, elevation, slantrange, ltp)` components (Aer4Tuple). Get method: aer4(self) - Get the `(azimuth, elevation, slantrange, ltp)` components (Aer4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### azimuth Get the Azimuth, bearing from North (`degrees360`). Get method: azimuth(self) - Get the Azimuth, bearing from North (`degrees360`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### down Get the Down component (`meter`). Get method: down(self) - Get the Down component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### east Get the East component (`meter`). Get method: east(self) - Get the East component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### elevation Get the Elevation, tilt above horizon (`degrees90`). Get method: elevation(self) - Get the Elevation, tilt above horizon (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### groundrange Get the ground range, distance (`meter`). Get method: groundrange(self) - Get the ground range, distance (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### north Get the North component (`meter`). Get method: north(self) - Get the North component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### slantrange Get the slant Range, distance (`meter`). Get method: slantrange(self) - Get the slant Range, distance (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### up Get the Up component (`meter`). Get method: up(self) - Get the Up component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### x Get the X component (`meter`). Get method: x(self) - Get the X component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz4 Get the `(x, y, z, ltp)` components (Xyz4Tuple). Get method: xyz4(self) - Get the `(x, y, z, ltp)` components (Xyz4Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### y Get the Y component (`meter`). Get method: y(self) - Get the Y component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### z Get the Z component (`meter`). Get method: z(self) - Get the Z component (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.